Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(276)

Unified Diff: webrtc/p2p/base/transportdescriptionfactory.h

Issue 1311903004: Replacing SSLIdentity* with scoped_refptr<RTCCertificate> in TransportDescriptionFactory layer (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « talk/session/media/mediasession_unittest.cc ('k') | webrtc/p2p/base/transportdescriptionfactory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/transportdescriptionfactory.h
diff --git a/webrtc/p2p/base/transportdescriptionfactory.h b/webrtc/p2p/base/transportdescriptionfactory.h
index 2bd86617ed6020cc4c9a1ecfc091c186bacdd7f1..828aa6d22c4f2fae6b0b7d233d2209d3095b9642 100644
--- a/webrtc/p2p/base/transportdescriptionfactory.h
+++ b/webrtc/p2p/base/transportdescriptionfactory.h
@@ -11,6 +11,7 @@
#ifndef WEBRTC_P2P_BASE_TRANSPORTDESCRIPTIONFACTORY_H_
#define WEBRTC_P2P_BASE_TRANSPORTDESCRIPTIONFACTORY_H_
+#include "webrtc/base/rtccertificate.h"
#include "webrtc/p2p/base/transportdescription.h"
namespace rtc {
@@ -33,13 +34,18 @@ class TransportDescriptionFactory {
// Default ctor; use methods below to set configuration.
TransportDescriptionFactory();
SecurePolicy secure() const { return secure_; }
- // The identity to use when setting up DTLS.
- rtc::SSLIdentity* identity() const { return identity_; }
+ // The certificate to use when setting up DTLS.
+ const rtc::scoped_refptr<rtc::RTCCertificate>& certificate() const {
+ return certificate_;
+ }
// Specifies the transport security policy to use.
void set_secure(SecurePolicy s) { secure_ = s; }
- // Specifies the identity to use (only used when secure is not SEC_DISABLED).
- void set_identity(rtc::SSLIdentity* identity) { identity_ = identity; }
+ // Specifies the certificate to use (only used when secure != SEC_DISABLED).
+ void set_certificate(
+ const rtc::scoped_refptr<rtc::RTCCertificate>& certificate) {
+ certificate_ = certificate;
+ }
// Creates a transport description suitable for use in an offer.
TransportDescription* CreateOffer(const TransportOptions& options,
@@ -55,7 +61,7 @@ class TransportDescriptionFactory {
ConnectionRole role) const;
SecurePolicy secure_;
- rtc::SSLIdentity* identity_;
+ rtc::scoped_refptr<rtc::RTCCertificate> certificate_;
};
} // namespace cricket
« no previous file with comments | « talk/session/media/mediasession_unittest.cc ('k') | webrtc/p2p/base/transportdescriptionfactory.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698